

class BlogCategoryController {

    def beforeInterceptor = [action:this.&checkUser,except:['index','list','show','details']]

    def checkUser() {
        if(!session.user) {
            // i.e. user not logged in
            redirect(controller:'user',action:'login',params:['targetCon':'blogcategory','targetAction':'manage'])
            return false
        }
    }
    
    def index = { redirect(action:manage,params:params) }

    // the delete, save and update actions only accept POST requests
    static allowedMethods = [delete:'POST', save:'POST', update:'POST']

    def list = {
		redirect(action:manage)
        params.max = Math.min( params.max ? params.max.toInteger() : 10,  100)
        [ blogCategoryInstanceList: BlogCategory.list( params ), blogCategoryInstanceTotal: BlogCategory.count() ]
    }

	def manage = {}

    def details = {}

    def show = {
        def blogCategoryInstance = BlogCategory.get( params.id )

        if(!blogCategoryInstance) {
            flash.message = "Category not found with id ${params.id}"
            redirect(action:manage)
        }
        else { return [ blogCategoryInstance : blogCategoryInstance ] }
    }

    def delete = {
        def blogCategoryInstance = BlogCategory.get( params.id )
        if(blogCategoryInstance) {
            try {
                blogCategoryInstance.delete(flush:true)
                flash.message = "Category deleted"
                redirect(action:manage)
            }
            catch(org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "Category ${params.name} could not be deleted"
                redirect(action:show,id:params.id)
            }
        }
        else {
            flash.message = "Category not found with id ${params.id}"
            redirect(action:manage)
        }
    }

    def edit = {
        def blogCategoryInstance = BlogCategory.get( params.id )

        if(!blogCategoryInstance) {
            flash.message = "Category not found with id ${params.id}"
            redirect(action:manage)
        }
        else {
            return [ blogCategoryInstance : blogCategoryInstance ]
        }
    }

    def update = {
        def blogCategoryInstance = BlogCategory.get( params.id )
        if(blogCategoryInstance) {
            if(params.version) {
                def version = params.version.toLong()
                if(blogCategoryInstance.version > version) {
                    
                    blogCategoryInstance.errors.rejectValue("version", "blogCategory.optimistic.locking.failure", "Another user has updated this Category while you were editing.")
                    render(view:'edit',model:[blogCategoryInstance:blogCategoryInstance])
                    return
                }
            }
            blogCategoryInstance.properties = params
            if(!blogCategoryInstance.hasErrors() && blogCategoryInstance.save()) {
                flash.message = "Category ${params.name} updated"
                redirect(action:manage)
            }
            else {
                render(view:'edit',model:[blogCategoryInstance:blogCategoryInstance])
            }
        }
        else {
            flash.message = "Category not found with id ${params.id}"
            redirect(action:manage)
        }
    }

    def create = {
        def blogCategoryInstance = new BlogCategory()
        blogCategoryInstance.properties = params
        return ['blogCategoryInstance':blogCategoryInstance]
    }

    def save = {
        def blogCategoryInstance = new BlogCategory(params)
        if(!blogCategoryInstance.hasErrors() && blogCategoryInstance.save()) {
            flash.message = "Category ${blogCategoryInstance.name} has been created"
            redirect(action:manage)
        }
        else {
            render(view:'create',model:[blogCategoryInstance:blogCategoryInstance])
        }
    }
}
