

class PostController {

    def beforeInterceptor = [action:this.&checkUser,except:['index','list','show']]

    def checkUser() {
        if(!session.user) {
            // i.e. user not logged in
            redirect(controller:'user',action:'login',params:['targetCon':'post','targetAction':'manage'])
            return false
        }
    }
    
    def index = { redirect(action:list,params:params) }

    // the delete, save and update actions only accept POST requests
    static allowedMethods = [delete:'POST', save:'POST', update:'POST']

    def list = {
        params.max = Math.min( params.max ? params.max.toInteger() : 10,  100)
        [ postInstanceList: Post.list( params ), postInstanceTotal: Post.count() ]
    }

	def manage = {}
	
	def details = {
		def postInstance = Post.get( params.id )

        if(!postInstance) {
            flash.message = "Post not found with id ${params.id}"
            redirect(action:manage)
        }
        else { return [ postInstance : postInstance ] }
	}

    def show = {
        def postInstance = Post.get( params.id )

        if(!postInstance) {
            flash.message = "Post not found with id ${params.id}"
            redirect(action:list)
        }
        else { return [ postInstance : postInstance ] }
    }

    def delete = {
        def postInstance = Post.get( params.id )
        if(postInstance) {
            try {
                postInstance.delete(flush:true)
                flash.message = "Post deleted"
                redirect(action:manage)
            }
            catch(org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "Post ${params.id} could not be deleted"
                redirect(action:details,id:params.id)
            }
        }
        else {
            flash.message = "Post not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def edit = {
        def postInstance = Post.get( params.id )

        if(!postInstance) {
            flash.message = "Post not found with id ${params.id}"
            redirect(action:list)
        }
        else {
            return [ postInstance : postInstance ]
        }
    }

    def update = {
        def postInstance = Post.get( params.id )
        if(postInstance) {
            if(params.version) {
                def version = params.version.toLong()
                if(postInstance.version > version) {
                    
                    postInstance.errors.rejectValue("version", "post.optimistic.locking.failure", "Another user has updated this Post while you were editing.")
                    render(view:'edit',model:[postInstance:postInstance])
                    return
                }
            }
            def cat = params['cat']
            params['cat'] = null
            postInstance.properties = params
            postInstance.categories.clear()
            cat.each
            {
                postInstance.addToCategories(BlogCategory.get(it))
            }

            if(!postInstance.hasErrors() && postInstance.save()) {
                flash.message = "Post updated"
                redirect(action:manage)
            }
            else {
                render(view:'edit',model:[postInstance:postInstance])
            }
        }
        else {
            flash.message = "Post not found with id ${params.id}"
            redirect(action:list)
        }
    }

    def create = {
        def postInstance = new Post()
        postInstance.properties = params
        return ['postInstance':postInstance]
    }

    def save = {
        params['date'] = new Date()
        def temp = params['cat']
        params['cat'] = null      
        params['user'] = User.findById(params['user'])
        def postInstance = new Post(params)

        if(temp)
        {
            temp.each
            {
                postInstance.addToCategories(BlogCategory.get(it))
            }
        }
        else
        {
            postInstance.addToCategories(BlogCategory.get(1))
        }

        if(!postInstance.hasErrors() && postInstance.save()) {
            flash.message = "Post has been added"
            redirect(action:manage)
        }
        else {
            render(view:'create',model:[postInstance:postInstance])
        }
    }
}
