

class UserController {

    def beforeInterceptor = [action:this.&checkUser,except:['login','dologin','dologout']]

    def checkUser() {
        if(!session.user) {
            // i.e. user not logged in
            redirect(controller:'user',action:'login',params:['targetCon':'user','targetAction':'manage'])
            return false
        }
    }

    def login = {}

    def dologin = {
        def user = User.findWhere(name:params['name'],password:params['password'])
        session.user = user
        if (user) {
            redirect(controller:params['targetCon'],action:params['targetAction'])
        } else {
            flash.message='Wrong username or password.'
            redirect(controller:'user',action:'login', params:['targetCon':params['targetCon'],'targetAction':params['targetAction']])
        }
    }

    def dologout = {
        if(!session.user) {
            redirect(controller:'post',action:'list')
        }
        flash.message='Logged out succesfully.'
        session.user = null;
    }
    
    def index = { redirect(action:manage,params:params) }

    // the delete, save and update actions only accept POST requests
    static allowedMethods = [delete:'POST', save:'POST', update:'POST']

    def list = {
		redirect(action:manage)
        params.max = Math.min( params.max ? params.max.toInteger() : 10,  100)
        [ userInstanceList: User.list( params ), userInstanceTotal: User.count() ]
    }

	def manage = {}

    def show = {
        def userInstance = User.get( params.id )

        if(!userInstance) {
            flash.message = "User not found with id ${params.id}"
            redirect(action:manage)
        }
        else { return [ userInstance : userInstance ] }
    }

    def delete = {
        def userInstance = User.get( params.id )
        if(userInstance) {
            try {
                userInstance.delete(flush:true)
                flash.message = "User deleted"
                redirect(action:manage)
            }
            catch(org.springframework.dao.DataIntegrityViolationException e) {
                flash.message = "User ${params.name} could not be deleted"
                redirect(action:show,id:params.id)
            }
        }
        else {
            flash.message = "User not found with id ${params.id}"
            redirect(action:manage)
        }
    }

    def edit = {
        def userInstance = User.get( params.id )

        if(!userInstance) {
            flash.message = "User not found with id ${params.id}"
            redirect(action:manage)
        }
        else {
            return [ userInstance : userInstance ]
        }
    }

    def update = {
        def userInstance = User.get( params.id )
        if(userInstance) {
            if(params.version) {
                def version = params.version.toLong()
                if(userInstance.version > version) {
                    
                    userInstance.errors.rejectValue("version", "user.optimistic.locking.failure", "Another user has updated this User while you were editing.")
                    render(view:'edit',model:[userInstance:userInstance])
                    return
                }
            }
            userInstance.properties = params
            if(!userInstance.hasErrors() && userInstance.save()) {
                flash.message = "User ${params.name} updated"
                redirect(action:manage)
            }
            else {
                render(view:'edit',model:[userInstance:userInstance])
            }
        }
        else {
            flash.message = "User not found with id ${params.id}"
            redirect(action:manage)
        }
    }

    def create = {
        def userInstance = new User()
        userInstance.properties = params
        return ['userInstance':userInstance]
    }

    def save = {
        def userInstance = new User(params)
        if(!userInstance.hasErrors() && userInstance.save()) {
            flash.message = "User ${userInstance.name} created"
            redirect(action:manage)
        }
        else {
            render(view:'create',model:[userInstance:userInstance])
        }
    }
}
